function [] = OF_PlotResiduals(fieldsArray)

% This tool will first run the foamJob ulitity and extract the information contained within the log
% file of an OpenFOAM case. This function requires the following input from the user:
%
% fieldsArray = this is a string array contaning the names of the fields for which residuals are
%		to be plotted e.g. ['U'; 'p'; 'k']
%
%
% Sample usage:
%
% OF_Runtime_PlotResiduals(['U'; 'p'; 'k']);
%
%
%


% Entering log directory to read files

cd logs

% Defining line formats to use

color = ['k'; 'b';'r';'g';'m';'y';]; % TODO: Add more colours
marker = ['x'; '+'; '*'; '^';  'v'; 's']; % TODO: Add more marker styles


% Identifying number of fields entered by user

[fieldsNo maximumSize] = size(fieldsArray);
if fieldsNo > length(color) % Currently 6 only
  disp('This function can only plot 6 fields at once. Reduce number of field for it work!')
  cd ..
  return
end

% Create file names from user entry (appending '_0')
% Only first iteration data will be plotted (i.e. foamLog files ending with '_0')

for i = 1:fieldsNo;
  fileName = strcat(fieldsArray(i,:),'_0');

  printf('Loading log file: %s\n', fileName)

% Loading residuals for specified fields
  data = dlmread(fileName,'\t');

  % Plotting residuals extracted
  h = plot(data(:,1),data(:,2),'color',color(i),'linestyle','-','linewidth',1);
  hold on;
  h2 = plot(data(1:25:length(data),1),data(1:25:length(data),2),'color',color(i),'linestyle','none', 'marker', marker(i), 'markersize',3);

  legend(h2,fieldsArray(i,:));
end

hold off % release plot to ensure it can be refreshed during runtime.

% Adjusting figure settings

set(gca,'YScale','log');
xlabel('No. Iteration');
ylabel('Residuals');


% Returning to case root directory (e.g. where '0' 'constant' and ''system' are located)

cd ..