function [vectors, scalars] = OF_Store_Probes(numberPointsInFile)
% This function enters the Probes directory and saves the probes locations
% into a Matlab/Octave file ready for plotting/further post-processing
%
% The data is stored as a structure array with the form:
% vectors.<vectorField>.point.<dataClassification> for vectors
% scalars.<scalarField>.point.<dataClassification> for scalars
%
% <dataClassification> includes x, y, x, vx, vy, vz elements (vectors)
% <dataClassification> includes x, y, x, p elements (scalars)

originalDir = pwd;

cd probes;

directories = dir;
[r c] = size(directories);
if r > 3; error('More than 1 directories within probes: Modify controlDict'); 
end

cd (directories(3).name)
fields = dir;
[r c] = size(fields);
fieldNo = r-2;
disp('')
printf('Probes directory contains %d fields\n', fieldNo);

%%%%% Start loop to evaluate all files within directory %%%%%
for i = 1:r
fileCheck = strfind(fields(i).name, '.');

if isempty(fileCheck) == 1;
disp('')
printf('Reading field %s\n',fields(i).name)


%%%%% Check whether SCALAR or VECTOR field %%%%%
fid = fopen((fields(i).name),'rt');

for line = 1:5; fileLine5 = fgetl(fid); end % This is not elegant
fclose(fid);
fileCheck = strfind(fileLine5, '(');

if isempty(fileCheck) == 0
disp('Calling OF_ReadProbesFile_Vector')
[vectorData] = OF_ReadProbesFile_Vector(numberPointsInFile, (fields(i).name));
vectors.(fields(i).name) = vectorData; % vector field data
else
disp('Calling OF_ReadProbesFile_Scalar')
[scalarData] = OF_ReadProbesFile_Scalar(numberPointsInFile, (fields(i).name));	
scalars.(fields(i).name) = scalarData; % scalar field data
end
end 
end

disp('Files in probes directory read and stored successfully')

%%%%% End evaluation loop %%%%% 

%%%%% Return to root directory %%%%%
cd (originalDir);

%%%%% Save data in matlab format ready for plotting %%%%%

% Check existance of 'OFMatData' directory and saves probes data %

OFMatDir = strcat((originalDir),'/OFMatData');
if exist((OFMatDir)) == 7
disp('OFMatData directory exists: Entering to save data')
cd (OFMatDir);
save -mat probes.mat vectors scalars
elseif exist((OFMatDir)) == 0
disp('OFMatData directory does not exists: Creating directory to save data')
mkdir (OFMatDir);
cd (OFMatDir);
save -mat probes.mat vectors scalars
else
error('This case is not set up correctly for use with this library')
end

%%%%% Return to root directory %%%%%
cd (originalDir);
