function [mu, nu, density] = GENERAL_airProperties(temperature)

% This function returns the dynamic and kinematic viscosity, as well as
% the air density for a given temperature (in Celsius). This function
% is valid for temperatures in the range -173 < T < 1327.
%
% The function has the form:
%
% [mu, nu, density] = GENERAL_airProperties(temperature)
%

T = [100 150 200 250 300 350 400 450 500 550 600 650 700 752 800 850 900 950 1000 1100 1200 1300 1400 1500 1600];	
T = T - 273;

muData = [0.6924 1.0283 1.3289 1.488 1.983 2.075 2.286 2.484 2.671 2.848 3.018 3.177 3.332 3.481 3.625 3.765 3.899 4.023 4.152 4.44 4.69 4.93 5.17 5.40 5.63]; 	
muData = muData*10^-5;

nuData = [1.923 4.343 7.490 9.49 15.68 20.76 25.90 28.86 37.90 44.34 51.34 58.51 66.25 73.91 82.29 90.75 99.30 108.2 117.8 138.6 159.1 182.1 205.5 229.1 254.5];
nuData = nuData*10^-6;

pmuData = polyfit(T,muData,5);
pnuData = polyfit(T,nuData,5); 	

figure()
hold
mu = polyval(pmuData,temperature);
plot(temperature, mu ,'*')
plot(T,polyval(pmuData,T))
xlabel('Temperature (celsius)')
ylabel('Dynamic viscosity (SI)')

figure()
hold
nu = polyval(pnuData,temperature);
plot(temperature, nu ,'*')
plot(T,polyval(pnuData,T))
xlabel('Temperature (celsius)')
ylabel('Kinematic viscosity (SI)')

density = mu/nu;
