function [] = SAMPLE_multipleProfiles(axisDir, axisDirRange, axisDirStations, axisNormal, axisNormalRange, axisConstant, axisConstantCoordinate)

% This function writes to file the entries required by sample to plot a series of
% profiles (sets) along a line. The function has the form:
%
% SAMPLE_multipleProfiles(
%	axisDir, axisDirRange, axisDirStations,
%	axisNormal, axisNormalRange, 
%	axisConstant, axisConstantCoordinate)
%
% Where,
% axisDir = axis along which the profiles will be taken e.g 'x' or 'X'
% axisDirRange = length of the axis line e.g. [0 3]
% axisDirStations = numer of profiles to be recorded
%
% axisNormal = direction normal to the axis e.g 'z' or 'Y'
% axisNormalRange = line along which the data will be extrated e.g [0 1]
% 
% axisConstant = axis perpendicular the the plane defined by axisDir 
%	         and axisNormal e.g 'z'
% axisConstantCoordinate = location of the plane defined by axisDir and 
%	         axisNormal e.g 2

fid = fopen('setProfiles','w');
profileSpacing = (axisDirRange(2) - axisDirRange(1))/axisDirStations;

if axisConstant == 'x' ||  axisConstant == 'X'
	xS = axisConstantCoordinate;
	xE = axisConstantCoordinate;
	elseif axisConstant == 'y' ||  axisConstant == 'Y'
	yS = axisConstantCoordinate;
	yE = axisConstantCoordinate;
	elseif axisConstant == 'z' ||  axisConstant == 'Z'
	zS = axisConstantCoordinate;
	zE = axisConstantCoordinate;
end

if axisNormal == 'x' || axisNormal == 'X'
	xS = axisNormalRange(1);
	xE = axisNormalRange(2);
	elseif axisNormal == 'y' ||  axisNormal == 'Y'
	yS = axisNormalRange(1);
	yE = axisNormalRange(2);
	elseif axisNormal == 'z' ||  axisNormal == 'Z'
	zS = axisNormalRange(1);
	zE = axisNormalRange(2);
end
	
for i = 1:axisDirStations
	if axisDir == 'x' || axisDir == 'X'
 	xS = axisDirRange(1) + profileSpacing*i;
	xE = axisDirRange(1) + profileSpacing*i;
	elseif axisDir == 'y' ||  axisDir == 'Y'
	yS = axisDirRange(1) + profileSpacing*i;
	yE = axisDirRange(1) + profileSpacing*i;
	elseif axisDir == 'z' ||  axisDir == 'Z'
	zS = axisDirRange(1) + profileSpacing*i;
	zE = axisDirRange(1) + profileSpacing*i;
	end
setName = strcat(axisDir,num2str(axisDirRange(1) + profileSpacing*i));
fprintf(fid,'%s\n',setName)
fprintf(fid,'{\n')
fprintf(fid,'type \t face;\n')
fprintf(fid,'axis \t distance;\n')
fprintf(fid,'start \t (%f %f %f);\n', xS, yS, zS)
fprintf(fid,'end \t (%f %f %f);\n', xE, yE, zE)
fprintf(fid,'}\n')
end
fclose(fid);
